@@ -20,16 +20,21 @@
 
 
 module APRS4R
-  APRS4RVersion = [0, 8, 1].join( '.')
+  APRS4RVersion = [0, 9, 1].join( '.')
 end
 
 path = ENV['APRS4R_ETC']
 path = "/etc/aprs4r" unless ENV['APRS4R_ETC']
 
+log4r_file = ENV['APRS4R_LOG4R']
+log4r_file = "log4r.yaml" unless ENV['APRS4R_LOG4R']
+
+print "log4r: #{path}/#{log4r_file}\n"
+
 require 'Logger'
 require 'Log4rConfigurator'
 
-Log4rConfigurator::configure_from_yaml_file( "#{path}/log4r.yaml")
+Log4rConfigurator::configure_from_yaml_file( "#{path}/#{log4r_file}")
 
 require 'aprs4r/APRS4RConfiguration'
 
@@ -37,6 +42,7 @@ require 'aprs4r/SocketManager'
 require 'aprs4r/BeaconManager'
 require 'aprs4r/DigipeaterManager'
 require 'aprs4r/GatewayManager'
+require 'aprs4r/PluginManager'
 
 
 # load aprs4r config
@@ -53,7 +59,7 @@ configuration = APRS4RConfiguration.loadConfiguration( file)
 # init aprs4r core module
 SocketManager.init( configuration)
 
-sleep 10
+sleep 2
 
 # start beacon block
 BeaconManager.init( configuration)
@@ -67,5 +73,9 @@ GatewayManager.start()
 DigipeaterManager.init( configuration)
 DigipeaterManager.start()
 
+# start generic plugin block
+PluginManager.init( configuration)
+PluginManager.start()
+
 sleep
 
