@@ -98,7 +98,7 @@ class ISSocket
       # send login sequence
       username = "user " + @username
       password = "pass " + @password
-      software = "vers aprs4r 0.8"
+      software = "vers aprs4r #{APRS4R::APRS4RVersion}"
       
       @socket.puts( username + " " + password + " " + software)
       @socket.puts( @filter)
